/*
 * Segment 6 Intelligente Bewertungsverfahren, SWE 6.1 Stauverlaufsanalyse
 * Copyright (C) 2007 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.ibv.anastau.migration.modell.verkehr.zustaende;

import de.bsvrz.ibv.anastau.migration.modell.Zustand;

/**
 * Definitionen für die Art der Mittelwertbildung bei der Datenerfassung.
 *
 * @author BitCtrl Systems GmbH, Peuker
 */
public enum ArtMittelwertBildung implements Zustand<Integer> {

	/** die Art ist nicht bekannt. */
	UNBEKANNT("unbekannt", -1),

	/** gleitende Mittelwertbildung. */
	GLEITEND("gleitende Mittelwertbildung", 0),

	/** arithmetischer Mittelwert. */
	ARITHMETISCH("arithmetische Mittelwertbildung", 1);

	/**
	 * liefert den Baustellenstatus mit dem übergebenen Code.
	 *
	 * @param gesuchterCode
	 *            der Code für den ein Zustand gesucht wird.
	 * @return der ermittelte Code, wenn ein ungültiger Code übergeben wurde,
	 *         wird eine der Status UNBEKANNT geliefert.
	 */
	public static ArtMittelwertBildung getStatus(final int gesuchterCode) {
		ArtMittelwertBildung result = ArtMittelwertBildung.UNBEKANNT;
		for (final ArtMittelwertBildung status : values()) {
			if (status.getCode() == gesuchterCode) {
				result = status;
				break;
			}
		}
		return result;

	}

	/**
	 * der Code des Zustandes.
	 */
	private int code;

	/**
	 * der Name des Zustandes.
	 */
	private String name;

	/**
	 * Konstruktor.<br>
	 * Die Funktion einen eine neue Instanz für die Art der Mittelwertbildung
	 * mit dem übergebenem Code und der entsprechenden Bezeichnung. Der
	 * Konstruktor wird nur innerhalb der Klasse verwendet. Es wird eine Menge
	 * vordefinierter Zustände zur Verfügung gestellt.
	 *
	 * @param name
	 *            der Name des zustands
	 * @param code
	 *            der verwendete Code
	 */
	ArtMittelwertBildung(final String name, final int code) {
		this.name = name;
		this.code = code;
	}

	/**
	 * liefert den Code des Zustandes.
	 *
	 * @return den Code.
	 */
	@Override
	public Integer getCode() {
		return code;
	}

	/**
	 * liefert den Namen des Zustandes.
	 *
	 * @return der Name
	 */
	@Override
	public String getName() {
		return name;
	}

}
